@@ -6,8 +6,6 @@ rustup target add x86_64-unknown-linux-gnu
 cargo build --target x86_64-unknown-linux-gnu
 cargo test --target x86_64-unknown-linux-gnu
 
-rustup component add rustfmt
-rustup component add clippy
 cargo fmt -- --check
 cargo clippy
 
